@@ -50,7 +50,7 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:ENUM,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:1) */
+/* BOOLEAN:ENUM,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:1) */
 void
 gth_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
                                 GValue       *return_value G_GNUC_UNUSED,
@@ -63,9 +63,9 @@ gth_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
                                                        gint         arg_1,
                                                        gint         arg_2,
                                                        gpointer     data2);
-  register GMarshalFunc_BOOLEAN__ENUM_ENUM callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__ENUM_ENUM callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -91,7 +91,7 @@ gth_marshal_BOOLEAN__ENUM_ENUM (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:VOID (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:2) */
+/* BOOLEAN:VOID (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:2) */
 void
 gth_marshal_BOOLEAN__VOID (GClosure     *closure,
                            GValue       *return_value G_GNUC_UNUSED,
@@ -102,9 +102,9 @@ gth_marshal_BOOLEAN__VOID (GClosure     *closure,
 {
   typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
                                                   gpointer     data2);
-  register GMarshalFunc_BOOLEAN__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -128,7 +128,7 @@ gth_marshal_BOOLEAN__VOID (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:BOOLEAN,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:3) */
+/* VOID:BOOLEAN,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:3) */
 void
 gth_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                    GValue       *return_value G_GNUC_UNUSED,
@@ -141,9 +141,9 @@ gth_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
                                                       gboolean     arg_1,
                                                       gpointer     arg_2,
                                                       gpointer     data2);
-  register GMarshalFunc_VOID__BOOLEAN_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__BOOLEAN_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -165,7 +165,7 @@ gth_marshal_VOID__BOOLEAN_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,BOXED (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:4) */
+/* VOID:BOXED,BOXED (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:4) */
 void
 gth_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                GValue       *return_value G_GNUC_UNUSED,
@@ -178,9 +178,9 @@ gth_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   gpointer     arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__BOXED_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__BOXED_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -202,7 +202,7 @@ gth_marshal_VOID__BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:ENUM,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:5) */
+/* VOID:ENUM,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:5) */
 void
 gth_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                              GValue       *return_value G_GNUC_UNUSED,
@@ -215,9 +215,9 @@ gth_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                                 gint         arg_1,
                                                 gint         arg_2,
                                                 gpointer     data2);
-  register GMarshalFunc_VOID__ENUM_ENUM callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__ENUM_ENUM callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -239,7 +239,7 @@ gth_marshal_VOID__ENUM_ENUM (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:6) */
+/* VOID:INT,INT (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:6) */
 void
 gth_marshal_VOID__INT_INT (GClosure     *closure,
                            GValue       *return_value G_GNUC_UNUSED,
@@ -252,9 +252,9 @@ gth_marshal_VOID__INT_INT (GClosure     *closure,
                                               gint         arg_1,
                                               gint         arg_2,
                                               gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -276,7 +276,7 @@ gth_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOOLEAN (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:7) */
+/* VOID:OBJECT,BOOLEAN (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:7) */
 void
 gth_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -289,9 +289,9 @@ gth_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gboolean     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -313,7 +313,7 @@ gth_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOXED,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:8) */
+/* VOID:OBJECT,BOXED,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:8) */
 void
 gth_marshal_VOID__OBJECT_BOXED_ENUM (GClosure     *closure,
                                      GValue       *return_value G_GNUC_UNUSED,
@@ -327,9 +327,9 @@ gth_marshal_VOID__OBJECT_BOXED_ENUM (GClosure     *closure,
                                                         gpointer     arg_2,
                                                         gint         arg_3,
                                                         gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_BOXED_ENUM callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOXED_ENUM callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -352,7 +352,7 @@ gth_marshal_VOID__OBJECT_BOXED_ENUM (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOXED,INT,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:9) */
+/* VOID:OBJECT,BOXED,INT,ENUM (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:9) */
 void
 gth_marshal_VOID__OBJECT_BOXED_INT_ENUM (GClosure     *closure,
                                          GValue       *return_value G_GNUC_UNUSED,
@@ -367,9 +367,9 @@ gth_marshal_VOID__OBJECT_BOXED_INT_ENUM (GClosure     *closure,
                                                             gint         arg_3,
                                                             gint         arg_4,
                                                             gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_BOXED_INT_ENUM callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_BOXED_INT_ENUM callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
@@ -393,7 +393,7 @@ gth_marshal_VOID__OBJECT_BOXED_INT_ENUM (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:10) */
+/* VOID:OBJECT,OBJECT (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:10) */
 void
 gth_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                  GValue       *return_value G_GNUC_UNUSED,
@@ -406,9 +406,9 @@ gth_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -430,7 +430,7 @@ gth_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,INT,INT,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:11) */
+/* VOID:OBJECT,OBJECT,INT,INT,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:11) */
 void
 gth_marshal_VOID__OBJECT_OBJECT_INT_INT_POINTER (GClosure     *closure,
                                                  GValue       *return_value G_GNUC_UNUSED,
@@ -446,9 +446,9 @@ gth_marshal_VOID__OBJECT_OBJECT_INT_INT_POINTER (GClosure     *closure,
                                                                     gint         arg_4,
                                                                     gpointer     arg_5,
                                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT_INT_INT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT_INT_INT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 6);
 
@@ -473,7 +473,7 @@ gth_marshal_VOID__OBJECT_OBJECT_INT_INT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:12) */
+/* VOID:OBJECT,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:12) */
 void
 gth_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                   GValue       *return_value G_GNUC_UNUSED,
@@ -486,9 +486,9 @@ gth_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                      gpointer     arg_1,
                                                      gpointer     arg_2,
                                                      gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -510,7 +510,7 @@ gth_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,STRING (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:13) */
+/* VOID:OBJECT,STRING (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:13) */
 void
 gth_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                  GValue       *return_value G_GNUC_UNUSED,
@@ -523,9 +523,9 @@ gth_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                                     gpointer     arg_1,
                                                     gpointer     arg_2,
                                                     gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -547,7 +547,7 @@ gth_marshal_VOID__OBJECT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,UINT (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:14) */
+/* VOID:OBJECT,UINT (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:14) */
 void
 gth_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                GValue       *return_value G_GNUC_UNUSED,
@@ -560,9 +560,9 @@ gth_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                                   gpointer     arg_1,
                                                   guint        arg_2,
                                                   gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_UINT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_UINT callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -584,7 +584,7 @@ gth_marshal_VOID__OBJECT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:15) */
+/* VOID:POINTER,POINTER (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:15) */
 void
 gth_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                    GValue       *return_value G_GNUC_UNUSED,
@@ -597,9 +597,9 @@ gth_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                       gpointer     arg_1,
                                                       gpointer     arg_2,
                                                       gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__POINTER_POINTER callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -621,7 +621,7 @@ gth_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,BOOLEAN,DOUBLE (/usr/src/ports/gthumb/gthumb-3.2.9.1-2.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:16) */
+/* VOID:STRING,STRING,BOOLEAN,DOUBLE (/usr/src/ports/gthumb/gthumb-3.2.9.1-3.i686/src/gthumb-3.2.9.1/gthumb/gth-marshal.list:16) */
 void
 gth_marshal_VOID__STRING_STRING_BOOLEAN_DOUBLE (GClosure     *closure,
                                                 GValue       *return_value G_GNUC_UNUSED,
@@ -636,9 +636,9 @@ gth_marshal_VOID__STRING_STRING_BOOLEAN_DOUBLE (GClosure     *closure,
                                                                    gboolean     arg_3,
                                                                    gdouble      arg_4,
                                                                    gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_BOOLEAN_DOUBLE callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING_BOOLEAN_DOUBLE callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 5);
 
